import React from 'react'
import Formsy, { HOC } from 'formsy-react'
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Box,
  Input,
  Pane,
  Content
} from '../components'

class _Field extends React.Component {
  render() {
    const {
      getValue,
      setValue
    } = this.props

    return (
      <div>
        <Input value={getValue()} onChange={(e) => setValue(e.target.value)} />
      </div>
    )
  }
}

const Field = HOC(_Field)

class ControlledForm extends React.Component {
  constructor() {
    super()
    this.submit = this.submit.bind(this)
  }

  submit() {

  }

  render() {
    return (
      <Formsy.Form onValidSubmit={this.submit}>
        <MyOwnInput name="email" validations="isEmail" validationError="This is not a valid email" required/>
        <button type="submit" disabled={!this.state.canSubmit}>Submit</button>
      </Formsy.Form>
    )
  }
}


export default function formsStory (module) {
  storiesOf('Forms', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={10}>
          <Content markdown>
{`
# Forms **WIP**

* Uses [formsy-react](https://github.com/christianalfoni/formsy-react)
* Show validation after submit
* After submit show validation messages onChange
* Avoid negative feedback (red colors, negative tone of voice)
* Show helpful information under a field when necessary
* Clicking labels should focus the corresponding field htmlFor + id
* Be lenient in what you accept

\`\`\`

\`\`\`

`}
          </Content>
          <Input />
          <Input warning />
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`warning\` | boolean | undefined | toggles \`<ExclamationCircle />\` on the side
`}
          </Content>
        </Pane>
      </App>
    ))
}
